package api

import (
	"net/http"
	"testing"
)

func TestPurchaseAddListMine(t *testing.T) {
	tapi := newTestAPI(t)
	defer tapi.close()
	tapi.addTestMember()
	tapi.addTestProducts()

	products := []PurchasedProduct{
		{
			ProductCode: testProduct.Code,
			Ammount:     5,
		},
	}
	resp := tapi.do("POST", "/purchase", products, nil)
	if resp.StatusCode != http.StatusCreated {
		t.Fatal("Can't create purchase:", resp.Status)
	}
	var purchases []Purchase
	resp = tapi.do("GET", "/purchase/mine", nil, &purchases)
	if resp.StatusCode != http.StatusOK {
		t.Fatal("Can't get purchases:", resp.Status)
	}

	if len(purchases) != 1 {
		t.Fatal("Wrong number of purchases", len(purchases), purchases)
	}
	if purchases[0].Total != testProduct.Price*products[0].Ammount {
		t.Error("Wrong total:", purchases[0].Total)
	}
	if len(purchases[0].Products) != 1 {
		t.Fatal("Wrong number of products", len(purchases[0].Products), purchases[0].Products)
	}
	if purchases[0].Products[0].ProductCode != testProduct.Code {
		t.Error("Wrong product code:", purchases[0].Products[0].ProductCode)
	}
	if purchases[0].Products[0].Price != testProduct.Price {
		t.Error("Wrong product price:", purchases[0].Products[0].Price)
	}

	var product Product
	resp = tapi.do("GET", "/product/234", nil, &product)
	if resp.StatusCode != http.StatusOK {
		t.Error("Can't find the product:", resp.Status)
	}
	if product.Stock != testProduct.Stock-products[0].Ammount {
		t.Error("Wrong product stock:", product)
	}

	var member Member
	resp = tapi.do("GET", "/member/10", nil, &member)
	if resp.StatusCode != http.StatusOK {
		t.Error("Can't find the member:", resp.Status)
	}
	if member.Balance != testMember.Balance-(testProduct.Price*products[0].Ammount) {
		t.Error("Wrong product balance:", member.Balance)
	}
}
